@@ -40,7 +40,7 @@ from calculate.lib.cl_log import log
 import hashlib
 import re
 import shutil
-from collections import MutableSet
+from collections.abc import MutableSet
 from contextlib import contextmanager
 import tempfile
 from fnmatch import fnmatch
@@ -156,8 +156,8 @@ class Update(MethodsInterface):
             EmergeCache.logger.logger.setLevel(logging.WARNING)
         self.emerge_cache.check_list = (
             self.emerge_cache.check_list +
-            map(lambda x:emerge_parser.GitCheckvalue(x, self.getGit()),
-                self.clVars.Get('update.cl_update_rep_path')))
+            [emerge_parser.GitCheckvalue(x, self.getGit()) for x 
+                in self.clVars.Get('update.cl_update_rep_path')])
         self.update_map = {}
         self.refresh_binhost = False
         self.pkgnum = None
@@ -370,7 +370,6 @@ class Update(MethodsInterface):
                     makeDirectory(reposdir)
                 os.rename(layman_fullname, repos_fullname)
                 os.symlink(symlink_target, layman_fullname)
-                #print "MYDEBUG", reposdir, laymandir, rpath_orig
                 self.endTask(True)
         return True
 
@@ -606,8 +605,8 @@ class Update(MethodsInterface):
             if path.exists(previous_eix):
                 os.unlink(previous_eix)
             try:
-                with writeFile(previous_eix) as f:
-                    f.write(readFile(portage_eix))
+                with writeFile(previous_eix, binary=True) as f:
+                    f.write(readFile(portage_eix, binary=True))
                 portage_eix_stat = os.stat(portage_eix)
                 os.chmod(previous_eix, portage_eix_stat.st_mode)
                 os.chown(previous_eix, portage_eix_stat.st_uid,
@@ -1474,7 +1473,7 @@ class Update(MethodsInterface):
             Binhosts.check_packages_signature(
                 url_binhost, orig_packages, gpg)
             with writeFile(packages_sign_fn) as f:
-                f.write(Binhosts.fetch_packages_sign(url_binhost))
+                f.write(Binhosts.fetch_packages_sign(url_binhost).decode("UTF-8"))
         except BinhostSignError:
             for fn in (packages_fn, packages_sign_fn):
                 if path.exists(fn):
@@ -1488,7 +1487,7 @@ class Update(MethodsInterface):
             raise
         return True
 
-    class Reason(object):
+    class Reason():
         Success = 0
         BadSign = 1
         Outdated = 2
@@ -1637,7 +1636,7 @@ class Update(MethodsInterface):
             packages_fn = self.clVars.Get('update.cl_update_package_cache')
             packages_sign_fn = self.clVars.Get('update.cl_update_package_cache_sign')
             if path.exists(packages_fn) and path.exists(packages_sign_fn):
-                packages_sign = readFile(packages_sign_fn)
+                packages_sign = readFile(packages_sign_fn, binary=True)
                 pi = PackagesIndex(readFile(packages_fn))
                 pi.clean()
                 try:
