@@ -1549,7 +1549,8 @@ class VariableClUpdateBinhostList(Variable):
     Список хостов с бинарными обновлениями
     """
     type = "list"
-    value = ["ftp://ftp.calculate-linux.ru/calculate"]
+    value = ["https://mirror.calculate-linux.org/"]
+    # value = ["ftp://ftp.calculate-linux.ru/calculate"]
 
 
 class VariableClUpdateBinhostUnstableList(Variable):
@@ -1557,7 +1558,8 @@ class VariableClUpdateBinhostUnstableList(Variable):
     Список хостов с бинарными обновлениями
     """
     type = "list"
-    value = ["ftp://ftp.calculate-linux.ru/testing"]
+    value = ["https://testing.calculate-linux.org/"]
+    # value = ["ftp://ftp.calculate-linux.ru/testing"]
 
 
 class VariableClUpdateBinhostBase(Variable):
